@@ -122,7 +122,9 @@ static void change_arg_use_in_operand
 static void validate_insns_of_varrefs PARAMS ((rtx insn));
 static void validate_operand_of_varrefs PARAMS ((rtx insn, rtx *loc));
 
+#ifndef SUSPICIOUS_BUF_SIZE
 #define SUSPICIOUS_BUF_SIZE 8
+#endif
 
 #define AUTO_BASEPTR(X) \
   (GET_CODE (X) == PLUS ? XEXP (X, 0) : X)
@@ -409,6 +411,7 @@ search_string_def (type)
 	       && TREE_CODE (TYPE_MAX_VALUE (TYPE_DOMAIN (type))) == NOP_EXPR))
 	    return TRUE;
 
+#if SUSPICIOUS_BUF_SIZE > 0
 	  /* Check if the string size is greater than SUSPICIOUS_BUF_SIZE */
 	  if (TYPE_MAX_VALUE (TYPE_DOMAIN (type)) != 0
 	      &&
@@ -417,6 +420,9 @@ search_string_def (type)
 	    return TRUE;
 
 	  current_function_defines_short_string = TRUE;
+#else
+	  return TRUE;
+#endif
 	}
       
       /* to protect every functions, sweep any arrays to the frame top */
